module.exports = defineTest({
	description: 'self-contained bundle'
});
